/**
 *
 *  This file is part of iliad-regutils.
 *
 *  Copyright (C) 2008 Martijn van der Horst <M.G.v.d.Horst@gmail.com>
 * 
 *  iliad-regutils is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This utility provides an interface to the registry for installing applications
 */

#ifndef REGUTIL_APPLICATION_INSTALL_H
#define REGUTIL_APPLICATION_INSTALL_H
#include "regutil.h"

// Structure describing the commandline options accepted by this utility
static struct argp_option regutil_application_install_options[] = {
  GLOBAL_OPTIONS
  {"appCategory",    'c', "CATEGORY",  0, "The application category"},
  {"argMask",        'm', "MASK",      0, "The argument mask for the application"},
  {"execute",        'e', "EXECUTABLE",0, "The executable of the application"},
  {"xResourceName",  'x', "RESOURCE",  0, "The x resource name of the application"},
  {"ipcChannel",     'p', "CHANNEL",   0, "The IPC channel of the application"},
  {"appIconPath",    'i', "ICON",      0, "The icon path of the application"},
  {"exticon",        'I', "ICON",      0, "The icon associated with the file extensions that are supported by the application"},
  {0}
};

// Structure that contains the arguments of the utility
typedef struct {
  char *application; // The application (type) to install
  char *appCategory; // The application category
  char *argMask;     // The argument mask
  char *execute;     // The executable
  char *xResourceName;// The x resource name
  char *ipcChannel;  // The IPC channel
  char *appIconPath; // The icon path
  char *exticon;     // The associated with the files supported by this applicaiton
  char **extensions; // The list of extensions supported by this application
} regutil_application_install_arguments;


// Function to set the argument structure to its default values
void regutil_application_install_init(void *args);

// Callback function for command line parsing
error_t regutil_application_install_callback(int key, char *arg, struct argp_state *state);

// Main function of the utility
int regutil_application_install_main(xmlDocPtr registry, global_arguments *arguments);

// Description of the utility
static utility_description regutil_application_install = {
  "registry-application-install",	// Name of the utility
  regutil_application_install_options,	// Command line options of the utility
  "APPLICATION [EXTENSION, ...]",       // Non-option arguments of the utility
  "This program installs APPLICATION in the registry and associates it as the default application for the file EXTENSIONs.",
  sizeof(regutil_application_install_arguments),// Size of the argument structure of the utility
  regutil_application_install_init,		// Function that initializes the argument structure
  regutil_application_install_callback,		// Callback function for command line parsing
  regutil_application_install_main		// Main function of the utility
};

#endif /*REGUTIL_APPLICATION_INSTALL_H*/
