/**
 *
 *  This file is part of iliad-regutils.
 *
 *  Copyright (C) 2008 Martijn van der Horst <M.G.v.d.Horst@gmail.com>
 * 
 *  iliad-regutils is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "regutil.h"
#include "regutil_application_remove.h"
#include <libxml/parser.h>
#include "vstrcat.h"

void regutil_application_remove_init(void *args) {
  regutil_application_remove_arguments *arguments = (regutil_application_remove_arguments *)args;

  // Set the default values in the argument structure
  arguments->application = NULL;
}

error_t regutil_application_remove_callback(int key, char *arg, struct argp_state *state) {
  error_t result = 0;
  global_arguments *arguments = state->input;
  regutil_application_remove_arguments *util_arguments = arguments->utility_arguments;

  switch (key) {
    case ARGP_KEY_ARG:
      if (state->arg_num == 0) util_arguments->application = arg; // This is the APPLICATION
      else argp_usage(state);                                     // This is one argument too many
      break;     
    case ARGP_KEY_END:
      if (state->arg_num != 1) argp_usage(state); // The APPLICATION argument was not given
      break;
    default:
      result = ARGP_ERR_UNKNOWN;
  }

  return result;
}

int regutil_application_remove_main(xmlDocPtr registry, global_arguments *arguments) {
  int error = 0;
  regutil_application_remove_arguments *util_arguments = arguments->utility_arguments;
  char *xpath = vstrcat("/iLiadRegistry/applications/application[@type='",util_arguments->application,"']",NULL);

  // Evaluate the xpath expression  
  xmlNodeSetPtr nodes = evaluate_xpath(registry, xpath, arguments->verbose);

  if (nodes == NULL) {
    fprintf(stderr,"Error: unable to evaluate xpath expression \"%s\"\n", xpath);
    error = -1;
  } else {
  
    // Determine whether the application is already in the registry or not
    if (nodes->nodeNr == 0) {

      // The extension does not exist
      if (arguments->verbose) fprintf(stdout,"The application was not found in the registry\n");
      // So we don't have to delete anything
      
    } else if (nodes->nodeNr == 1) {
      // The application exists
      
      // Delete the application:
      arguments->changed = remove_nodes(nodes, arguments->verbose);
      
      // Delete the file extensions:
      char *xpath_extensions = vstrcat("/iLiadRegistry/extensionInfos/extensionInfo[associateApp='",util_arguments->application,"']",NULL);
      xmlNodeSetPtr nodes_extensions = evaluate_xpath(registry, xpath_extensions, arguments->verbose);
      // FIXME: We should do some error handling here
      if (nodes_extensions != NULL) arguments->changed = remove_nodes(nodes_extensions, arguments->verbose) || arguments->changed;

    } else {
      // There are multiple entries
      // PANIC
      // FIXME: Do something other than panic
      fprintf(stderr,"The application \"%s\" is in the registry %d times.\nRefusing to continue\n", util_arguments->application,
      nodes->nodeNr);
      error = -1;
    }
  
    // Cleanup
    xmlXPathFreeNodeSet(nodes);
  }

  free(xpath);
  
  return error;
}
