/**
 *
 *  This file is part of iliad-regutils.
 *
 *  Copyright (C) 2008 Martijn van der Horst <M.G.v.d.Horst@gmail.com>
 * 
 *  iliad-regutils is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This utility provides removes an application and its associated file extensions from the registry
 */

#ifndef REGUTIL_APPLICATION_REMOVE_H
#define REGUTIL_APPLICATION_REMOVE_H
#include "regutil.h"

// Structure describing the commandline options accepted by this utility
static struct argp_option regutil_application_remove_options[] = {
  GLOBAL_OPTIONS
  {0}
};

// Structure that contains the arguments of the utility
typedef struct {
  char *application;	// The application to remove
} regutil_application_remove_arguments;


// Function to set the argument structure to its default values
void regutil_application_remove_init(void *args);

// Callback function for command line parsing
error_t regutil_application_remove_callback(int key, char *arg, struct argp_state *state);

// Main function of the utility
int regutil_application_remove_main(xmlDocPtr registry, global_arguments *arguments);

// Description of the utility
static utility_description regutil_application_remove = {
  "registry-application-remove",	// Name of the utility
  regutil_application_remove_options,	// Command line options of the utility
  "APPLICATION",			// Non-option arguments of the utility
  "This program removes APPLICATION and its associated file types from the registry, where APPLICATION matches the type attribute in the registry.",
  sizeof(regutil_application_remove_arguments),	// Size of the argument structure of the utility
  regutil_application_remove_init,		// Function that initializes the argument structure
  regutil_application_remove_callback,		// Callback function for command line parsing
  regutil_application_remove_main		// Main function of the utility
};

#endif /*REGUTIL_APPLICATION_REMOVE_H*/
