/**
 *
 *  This file is part of iliad-regutils.
 *
 *  Copyright (C) 2008 Martijn van der Horst <M.G.v.d.Horst@gmail.com>
 * 
 *  iliad-regutils is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "regutil.h"
#include "regutil_default.h"
#include <libxml/parser.h>

void regutil_default_init(void *args) {
  regutil_default_arguments *arguments = (regutil_default_arguments *)args;

  // Set the default values in the argument structure
  arguments->xpath = "";
  arguments->delete = 0;
  arguments->value = NULL;
}

error_t regutil_default_callback(int key, char *arg, struct argp_state *state) {
  error_t result = 0;
  global_arguments *arguments = state->input;
  regutil_default_arguments *util_arguments = arguments->utility_arguments;

  switch (key) {
    case 'd':
      util_arguments->delete = 1;
      break;
    case 's':
      util_arguments->value = arg;
      break;
    case ARGP_KEY_ARG:
      if (state->arg_num == 0) util_arguments->xpath = arg; // This is the XPATH
      else argp_usage(state);                               // This is one argument too many
      break;     
    case ARGP_KEY_END:
      if (state->arg_num != 1) argp_usage(state); // The XPATH argument was not given
      break;
    default:
      result = ARGP_ERR_UNKNOWN;
  }

  return result;
}

static void shownodes(xmlDocPtr registry, xmlNodeSetPtr nodes) {
  int i;
  
  // Dump the nodes to stdout
  for (i = 0; i < nodes->nodeNr; i++) {
    fprintf(stdout, "-- NODE --\n");
    xmlNodePtr node = nodes->nodeTab[i];
    xmlElemDump(stdout, registry, node);
    fprintf(stdout, "\n");
  }
}

int regutil_default_main(xmlDocPtr registry, global_arguments *arguments) {
  int error = 0;
  regutil_default_arguments *util_arguments = arguments->utility_arguments;

  // Evaluate the xpath expression  
  xmlNodeSetPtr nodes = evaluate_xpath(registry, util_arguments->xpath, arguments->verbose);

  if (nodes == NULL) {
    fprintf(stderr,"Error: unable to evaluate xpath expression \"%s\"\n", util_arguments->xpath);
    error = -1;
  } else {
  
    if (util_arguments->delete) {
      // Delete the nodes
      arguments->changed = remove_nodes(nodes, arguments->verbose);
    } else if (util_arguments->value != NULL) {
      // Set the value of the nodes
      arguments->changed = update_nodes(nodes, util_arguments->value, arguments->verbose);
    } else {
      // Print the value of the nodes
      shownodes(registry, nodes);
    }
  
    // Cleanup
    xmlXPathFreeNodeSet(nodes);
  }
  
  return error;
}
