/**
 *
 *  This file is part of iliad-regutils.
 *
 *  Copyright (C) 2008 Martijn van der Horst <M.G.v.d.Horst@gmail.com>
 * 
 *  iliad-regutils is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This utility provides a very basic interface to the registry
 * it is also the default utility when the name of the utility cannot be found
 */

#ifndef REGUTIL_DEFAULT_H
#define REGUTIL_DEFAULT_H
#include "regutil.h"

// Structure describing the commandline options accepted by this utility
static struct argp_option regutil_default_options[] = {
  GLOBAL_OPTIONS
  {"delete", 'd', 0,       0, "Delete the nodes in the XPATH from the registry"},
  {"set",    's', "VALUE", 0, "Set the nodes in the XPATH to VALUE"},
  {0}
};

// Structure that contains the arguments of the utility
typedef struct {
  char *xpath;  // Path to the node(s) to be edited
  int delete;   // Delete the node(s)
  char *value;  // New value for the nodes
} regutil_default_arguments;


// Function to set the argument structure to its default values
void regutil_default_init(void *args);

// Callback function for command line parsing
error_t regutil_default_callback(int key, char *arg, struct argp_state *state);

// Main function of the utility
int regutil_default_main(xmlDocPtr registry, global_arguments *arguments);

// Description of the utility
static utility_description regutil_default = {
  "default",			// Name of the utility
  regutil_default_options,	// Command line options of the utility
  "XPATH",			// Non-option arguments of the utility
  "This program evaluates the XPATH expression on the registry and prints the result. Alternatively, the options can be used to alter the nodes indicated by the XPATH expression.\vWARNING: This program does not check your modifications, you may screw up your registry. The other regutil programs can be used to alter the registry in a safer way.",
  sizeof(regutil_default_arguments),	// Size of the argument structure of the utility
  regutil_default_init,			// Function that initializes the argument structure
  regutil_default_callback,		// Callback function for command line parsing
  regutil_default_main			// Main function of the utility
};

#endif /*REGUTIL_DEFAULT_H*/
