/**
 *
 *  This file is part of iliad-regutils.
 *
 *  Copyright (C) 2008 Martijn van der Horst <M.G.v.d.Horst@gmail.com>
 * 
 *  iliad-regutils is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This utility provides an interface to the registry for handling file extensions
 */

#ifndef REGUTIL_EXTENSION_H
#define REGUTIL_EXTENSION_H
#include "regutil.h"

// Structure describing the commandline options accepted by this utility
static struct argp_option regutil_extension_options[] = {
  GLOBAL_OPTIONS
  {"delete",  'd', 0,       0, "Remove the extension from the registry"},
  {"get-icon",'i', 0,       0, "Print the icon associated with the extension"},
  {"set-icon",'I', "ICON",  0, "Set the icon associated with the extension to ICON"},
  {"get-app", 'a', 0,       0, "Print the application associated with the extension"},
  {"set-app", 'A', "APP",   0, "Set the application associated with the extension to APP"},
  {0}
};

// Structure that contains the arguments of the utility
typedef struct {
  char *extension; // The extension to modify
  int delete;      // Delete the extension
  int show_icon;   // Boolean indicating to print the icon
  char *icon;      // New icon for the extension
  int show_app;    // Boolean indicating to print the application
  char *app;       // New application for the extension
} regutil_extension_arguments;


// Function to set the argument structure to its default values
void regutil_extension_init(void *args);

// Callback function for command line parsing
error_t regutil_extension_callback(int key, char *arg, struct argp_state *state);

// Main function of the utility
int regutil_extension_main(xmlDocPtr registry, global_arguments *arguments);

// Description of the utility
static utility_description regutil_extension = {
  "registry-extension",		// Name of the utility
  regutil_extension_options,	// Command line options of the utility
  "EXTENSION",			// Non-option arguments of the utility
  "This program updates the settings for file extension EXTENSION in the registry, or prints the current settings.",
  sizeof(regutil_extension_arguments),	// Size of the argument structure of the utility
  regutil_extension_init,		// Function that initializes the argument structure
  regutil_extension_callback,		// Callback function for command line parsing
  regutil_extension_main		// Main function of the utility
};

#endif /*REGUTIL_EXTENSION_H*/
