/**
 *
 *  This file is part of iliad-regutils.
 *
 *  Copyright (C) 2008 Martijn van der Horst <M.G.v.d.Horst@gmail.com>
 * 
 *  iliad-regutils is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <argp.h>
#include <string.h>
#include <stdlib.h>
#include "regutil.h"
#include "regutil_utilities.h"
#include "regutil_default.h"
#include "regutil_extension.h"
#include "regutil_application_remove.h"
#include "regutil_application_install.h"

// List of all the utilities
static utility_description *utility_list[] = {
  &regutil_default,
  &regutil_extension,
  &regutil_application_remove,
  &regutil_application_install,
  NULL
};

// Returns a number identifying the utility by name
int identify_utility(char *name) {
  int result = 0;
  int idx = 0;
  utility_description *util = utility_list[idx];
  
  do {  
    if (strcmp(util->name,name) == 0) result = idx;
    idx++;
    util = utility_list[idx];
  } while ((result == 0) && (util != NULL));

  return result;  
}

// Returns a command line parser for the utility
// The caller is responsible for freeing the parser.
struct argp *get_parser(int id) {
  struct argp *result = malloc(sizeof(struct argp));
  
  result->options = utility_list[id]->options;
  result->parser = global_parser_callback;
  result->args_doc = utility_list[id]->args_doc;
  result->doc = utility_list[id]->doc;
  result->children = 0;
  result->help_filter = 0;
  result->argp_domain = 0;

  return result;
}

// Returns the argument structure for the parsing the command line parameters
global_arguments *get_argument_structure(int id) {
  global_arguments *result = malloc(sizeof(global_arguments));

  // Default settings
  result->verbose = 0;
  result->file = ILIAD_REGISTRY;
  
  // Utility specific settings
  result->utility_callback = utility_list[id]->callback;
  result->utility_arguments = malloc(utility_list[id]->argument_size);
  utility_list[id]->init_arguments(result->utility_arguments);

  // So far the registry had not been changed
  result->changed = 0;

  return result;
}

void free_argument_structure(global_arguments *args) {
  free(args->utility_arguments);
  free(args);
}

utility_main get_utility_main(int id) {
  return utility_list[id]->main;
}
